import { DemensionStoreInter } from '../types/store'
import { defineStore } from 'pinia'
import $axios from '@/api'
import { $getDemension } from '@/utils/utils'

export const useDemensionListStore = defineStore({
  id: 'demensionList',
  state: () => {
    return <DemensionStoreInter>{
      pageNum: 1,
      pageSize: 10,
      deleted: 0,
      entityType: 2,
      entityName: '',
      entityId: '',
      totalNum: 0,
      totalPage: 0,
      selectDemension: {},
      dataList: [],
      tabInfo: {
        totalNumList: [0, 0]
      }
    }
  },
  actions: {
    //初始化列表状态
    clearState() {
      this.pageNum = 1
      this.pageSize = 10
      this.totalNum = 0
      this.totalPage = 0
      this.dataList = []
    },
    getDemension() {
      //先清除历史的状态
      this.clearState()
      const demensionInfo = $getDemension()

      //首页返回所有维度列表，列表页正常返回
      if (demensionInfo.selectDemension) {
        this.selectDemension = demensionInfo.selectDemension
      } else {
        return demensionInfo.allDemensionArr
      }

      //有tab的列表
      if (demensionInfo.selectDemension.tabs === 'deleted') {
        this.getDeletedList()
        return
      }

      this.getList()
    },

    //有历史tab页的请求，自定义请求获取额外数据
    async getDeletedList() {
      this.deleted = 1
      const totalNum1 = await (await this.getList()).totalNum
      this.dataList = []
      this.deleted = 0
      const totalNum2 = await (await this.getList()).totalNum
      this.tabInfo.totalNumList = [totalNum2, totalNum1]
      // console.log()
    },

    async getList(extraParams?: {}) {
      //发起请求
      const { pageNum, pageSize, deleted, entityType, entityName, entityId } = this
      const params = {
        dimensionCode: this.selectDemension?.code,
        pageNum,
        pageSize,
        deleted,
        entityType,
        entityName,
        entityId,
        ...extraParams
      }
      const res = await $axios.get('lawyer-workbench/risk/dimension/page', { params }) as { totalNum: number, totalPage: number, dataList: [] }
      this.totalNum = res.totalNum
      this.totalPage = res.totalPage
      this.dataList.push(...res.dataList)
      return res
    }
  }
})
